@@ -1,7 +1,7 @@
 #' @exportS3Method
 print.bartcs <- function(x, ...) {
   cat(
-    "`bartcs` fit by `", x$model, "()`",
+    "`bartcs` fit by `", x$model, "_bart()`",
     "\n\n", sep = ""
   )
 
@@ -16,5 +16,4 @@ print.bartcs <- function(x, ...) {
   )
   colnames(df) <- c("mean", "2.5%", "97.5%")
   print(df)
-  cat("\n")
 }
